@@ -3,7 +3,7 @@ from __future__ import with_statement
 import os
 import re
 from helper import json, shell_exec, mkdir_p, rmdir, kill_pid
-from exception import SftpConfigException
+from exception import SftpConfigException, SftpMountException
 
 
 class EnvironmentModel(object):
@@ -13,7 +13,8 @@ class EnvironmentModel(object):
 
     def __init__(self):
         self.mount_path_base = '/mnt/sshfs/'
-        self.config_path_base = os.path.expanduser('~/.config/sftpman/')
+        cfg_home = os.getenv('XDG_CONFIG_HOME', os.path.expanduser('~/.config'))
+        self.config_path_base = "%s/" % os.path.join(cfg_home, 'sftpman')
         self.config_path_mounts = '%smounts/' % self.config_path_base
 
     def get_system_config_path(self, system_id):
@@ -221,7 +222,7 @@ class SystemControllerModel(object):
         """Ensures the mount location exists, so we can start using it."""
 
         # Ensure nothing's mounted there right now..
-        shell_exec("/bin/fusermount -u %s 2>&1" % self.mount_point_local)
+        shell_exec('/bin/fusermount -u %s' % self.mount_point_local)
 
         # Ensure the directory path exists
         mkdir_p(self.mount_point_local)
@@ -243,8 +244,7 @@ class SystemControllerModel(object):
 
         cmd = ("{cmd_before_mount} &&"
                " /usr/bin/sshfs -o ssh_command='/usr/bin/ssh -p {port} -i {key}'"
-               " {sshfs_options} {user}@{host}:{remote_path} {local_path}"
-               " > /dev/null 2>&1")
+               " {sshfs_options} {user}@{host}:{remote_path} {local_path}")
         cmd = cmd.format(
             cmd_before_mount = self.system.cmd_before_mount,
             port = self.system.port,
@@ -256,11 +256,14 @@ class SystemControllerModel(object):
             local_path = self.mount_point_local,
         )
 
-        shell_exec(cmd)
+        output = shell_exec(cmd).strip()
 
-        # Clean up the directory tree if mounting failed
         if not self.mounted:
+            # Clean up the directory tree
             self._mount_point_local_delete()
+            if output == '':
+                output = 'Mounting failed for a reason unknown to sftpman.'
+            raise SftpMountException(cmd, output)
 
     def unmount(self):
         """Unmounts the sftp system if it's currently mounted."""
@@ -268,7 +271,7 @@ class SystemControllerModel(object):
             return
 
         # Try to unmount properly.
-        cmd = "/bin/fusermount -u %s > /dev/null 2>&1" % self.mount_point_local
+        cmd = '/bin/fusermount -u %s' % self.mount_point_local
         shell_exec(cmd)
 
         # The filesystem is probably still in use.
